StepArg

Enum StepArg 

pub enum StepArg {
    Fixed(f32),
    Variable(ParamArg),
}
A fixed operation value or a value interpolated from a normalized linkage parameter.

Fluent *_param methods create the Variable form and map a normalized parameter to an operation range. See the canonical linkage example.

Rotation arguments are stored as radians. Translation arguments are stored as linkage distances.

Variants



Fixed(f32)

A fixed rotation in radians or fixed translation in linkage units.



Variable(ParamArg)

A value interpolated from a normalized linkage parameter.